#!/usr/bin/env python

"""
Common handler functionality for different entities.
"""

from imiptools.content import to_part

class CommonFreebusy:

    "Common free/busy mix-in."

    def request(self):

        """
        Respond to a request by preparing a reply containing free/busy
        information for each indicated attendee.
        """

        oa = self.require_organiser_and_attendees()
        if not oa:
            return None

        (organiser, organiser_attr), attendees = organiser_item, attendees = oa

        # Validate the organiser, ignoring spoofed requests.

        if not self.validate_identities([organiser_item]):
            return None

        # Construct an appropriate fragment.

        calendar = []
        cwrite = calendar.append

        # Get the details for each attendee.

        for attendee, attendee_attr in attendees.items():
            freebusy = self.store.get_freebusy(attendee)

            record = []
            rwrite = record.append

            rwrite(("ORGANIZER", organiser_attr, organiser))
            rwrite(("ATTENDEE", attendee_attr, attendee))
            rwrite(("UID", {}, self.uid))

            if freebusy:
                for start, end, uid, transp in freebusy:
                    if transp == "OPAQUE":
                        rwrite(("FREEBUSY", {"FBTYPE" : "BUSY"}, "/".join([start, end])))

            cwrite(("VFREEBUSY", {}, record))

        # Return the reply.

        return "REPLY", to_part("REPLY", calendar)

# vim: tabstop=4 expandtab shiftwidth=4
